@@ -1,4 +1,3 @@
-#!/usr/bin/env python3
 #
 # Copyright (c) 2020-2022 Julian Heinovski <heinovski@ccs-labs.org>
 #
@@ -22,6 +21,7 @@ import pickle
 import sys
 import textwrap
 from distutils.util import strtobool
+from signal import SIGINT, signal
 from timeit import default_timer as timer
 
 from plafosim import __version__
@@ -715,6 +715,11 @@ def main():
         print(f"Saved a snapshot of the simulation to {args.save_snapshot}. Exiting...")
         return
 
+    def handler(signal, frame):
+        simulator.stop("SIGINT or CTRL-C detected!")
+
+    signal(SIGINT, handler)
+
     # execute simulation
     start_time = timer()
 
@@ -727,4 +732,4 @@ def main():
 
 
 if __name__ == "__main__":
-    main()
+    sys.exit(main())
