@@ -1,4 +1,3 @@
-#!/usr/bin/env python3
 #
 # Copyright (c) 2020-2022 Julian Heinovski <heinovski@ccs-labs.org>
 #
@@ -18,7 +17,6 @@
 
 import argparse
 import logging
-import os
 import sys
 import textwrap
 import time
@@ -30,6 +28,7 @@ from plafosim import __version__
 from plafosim.gui import (
     add_gui_vehicle,
     change_gui_vehicle_color,
+    check_and_prepare_gui,
     close_gui,
     gui_step,
     move_gui_vehicle,
@@ -41,11 +40,6 @@ from plafosim.util import find_resource, hex2rgb
 
 LOG = logging.getLogger(__name__)
 
-if 'SUMO_HOME' not in os.environ:
-    sys.exit("ERROR: Environment variable 'SUMO_HOME' was not declared!")
-tools = os.path.join(os.environ['SUMO_HOME'], 'tools')
-sys.path.append(tools)
-
 
 class CustomFormatter(
     argparse.ArgumentDefaultsHelpFormatter,
@@ -149,6 +143,18 @@ def parse_args() -> argparse.Namespace:
         help="The last step to re-play from the trace file. -1 is no limit"
     )
 
+    # print usage without any arguments
+    if len(sys.argv) < 2:
+        # no argument has been passed
+        print(
+            parser.description,
+            '\n',
+            parser.format_usage(),
+            sep='',
+            end='',
+        )
+        sys.exit(0)
+
     return parser.parse_args()
 
 
@@ -158,6 +164,7 @@ def main():
     # TODO add custom filter that prepends the log entry with the step time
     logging.basicConfig(level=args.log_level.upper(), format="%(levelname)s [%(name)s]: %(message)s")
 
+    check_and_prepare_gui()
     start_gui(config=args.sumo_config)
 
     LOG.info("Replaying vehicle trace...")
@@ -207,4 +214,4 @@ def main():
 
 
 if __name__ == "__main__":
-    main()
+    sys.exit(main())
