@@ -16,7 +16,6 @@
 #
 
 import logging
-import os
 import random
 import sys
 import time
@@ -30,6 +29,7 @@ from tqdm import tqdm
 from .emissions import EmissionClass
 from .gui import (
     add_gui_vehicle,
+    check_and_prepare_gui,
     close_gui,
     draw_infrastructures,
     draw_ramps,
@@ -304,7 +304,7 @@ class Simulator:
         """Initializes a simulator instance."""
 
         # TODO add custom filter that prepends the log entry with the step time
-        logging.basicConfig(level=log_level, format="%(levelname)s [%(name)s]: %(message)s")
+        logging.basicConfig(level=log_level, stream=sys.stdout, format="%(levelname)s [%(name)s]: %(message)s")
 
         # road network properties
         self._road_length = road_length  # the length of the road
@@ -475,10 +475,8 @@ class Simulator:
         # gui properties
         self._gui = gui  # whether to show a live sumo-gui
         if gui:
-            if 'SUMO_HOME' not in os.environ:
-                sys.exit("ERROR: Environment variable 'SUMO_HOME' was not declared!")
-            tools = os.path.join(os.environ['SUMO_HOME'], 'tools')
-            sys.path.append(tools)
+            check_and_prepare_gui()
+
             if road_length > 1000 * 1000:
                 sys.exit("ERROR: The current maximum road length supported in the GUI is 1000km!")
             if number_of_lanes > 4:
@@ -980,6 +978,8 @@ class Simulator:
         self._vehicle_spawn_queue = not_spawned_vehicles
         assert len({v['vid'] for v in self._vehicle_spawn_queue}) == len(self._vehicle_spawn_queue)
 
+        return len(spawned_vehicles_df)
+
     def _is_insert_unsafe(self, depart_position, depart_speed, vtype, other_vehicle):
         # would it be unsafe to insert the vehicle?
         if other_vehicle._position <= depart_position:
@@ -1303,7 +1303,7 @@ class Simulator:
                 self._initialize_gui()
 
             # spawn vehicle based on given parameters
-            self._spawn_vehicles(self._get_vehicles_df())
+            vehicles_spawned = self._spawn_vehicles(self._get_vehicles_df())
 
             vehicles_in_simulator = len(self._vehicles)
             vehicles_in_queue = len(self._vehicle_spawn_queue)
@@ -1397,7 +1397,13 @@ class Simulator:
 
             # record some periodic statistics
             run_time = end_time - start_time
-            self._statistics(vehicles_in_simulator, vehicles_in_queue, run_time)
+            self._statistics(
+                vehicles_in_simulator=vehicles_in_simulator,
+                vehicles_in_queue=vehicles_in_queue,
+                vehicles_spawned=vehicles_spawned,
+                vehicles_arrived=len(arrived_vehicles),
+                runtime=run_time,
+            )
 
             # a new step begins
             self._step += self._step_length
@@ -1412,7 +1418,14 @@ class Simulator:
 
         return self._step
 
-    def _statistics(self, vehicles_in_simulator, vehicles_in_queue, runtime: float):
+    def _statistics(
+            self,
+            vehicles_in_simulator: int,
+            vehicles_in_queue: int,
+            vehicles_spawned: int,
+            vehicles_arrived: int,
+            runtime: float
+    ):
         """Record some period statistics."""
 
         self._avg_number_vehicles = int(
@@ -1427,6 +1440,8 @@ class Simulator:
                 step=self._step,
                 vehicles_in_simulator=vehicles_in_simulator,
                 vehicles_in_queue=vehicles_in_queue,
+                vehicles_spawned=vehicles_spawned,
+                vehicles_arrived=vehicles_arrived,
                 runtime=runtime,
             )
 
@@ -1664,6 +1679,7 @@ def compute_vehicle_spawns(
         vehicle_after_spawn_position = (
             vdf
             .loc[vdf.position >= spawn_position]
+            .query('lane == 0')
             .sort_values("position", ascending=True)
             .iloc[0]
         )
@@ -1674,6 +1690,7 @@ def compute_vehicle_spawns(
         vehicle_before_spawn_position = (
             vdf
             .loc[vdf.position < spawn_position]
+            .query('lane == 0')
             .sort_values("position", ascending=True)
             .iloc[-1]
         )
