@@ -18,6 +18,8 @@
 import time
 from typing import TYPE_CHECKING
 
+from plafosim import __version__
+
 from .formation_algorithm import FormationAlgorithm
 from .util import rgb2hex
 
@@ -33,7 +35,8 @@ def record_general_data_begin(basename: str, simulator: 'Simulator'):
     assert isinstance(simulator, Simulator)
     with open(f'{basename}_general.out', 'w') as f:
         f.write(f"simulation start: {time.asctime(time.localtime(time.time()))}\n")
-        f.write(f"parameters {str(simulator)}\n")
+        f.write(f"version: {__version__}\n")
+        f.write(f"parameters:\n{str(simulator)}\n")
 
 
 def record_general_data_end(basename: str, simulator: 'Simulator'):
@@ -379,10 +382,10 @@ def record_vehicle_trace(basename: str, step: int, vehicle: 'Vehicle'):
             f"{vehicle._blocked_front},"
             f"{vehicle.travel_time},"
             f"{vehicle.travel_distance},"
-            f"{vehicle.desired_speed},"  # use potential other desired driving speed
+            f"{vehicle.desired_speed},"  # use potential platoon desired driving speed
             f"{vehicle._cf_target_speed},"
             f"{vehicle._cf_model.name},"
-            f"{rgb2hex(vehicle._color)}"
+            f"{rgb2hex(vehicle.color)}"  # use potential platoon color
             "\n"
         )
 
@@ -619,6 +622,8 @@ def initialize_simulation_trace(basename: str):
             "step,"
             "numberOfVehicles,"
             "vehiclesInSpawnQueue,"
+            "vehiclesSpawned,"
+            "vehiclesArrived,"
             "executionTime"
             "\n"
         )
@@ -629,6 +634,8 @@ def record_simulation_trace(
         step: int,
         vehicles_in_simulator: int,
         vehicles_in_queue: int,
+        vehicles_spawned: int,
+        vehicles_arrived: int,
         runtime: float
 ):
     assert basename
@@ -637,6 +644,8 @@ def record_simulation_trace(
             f"{step},"
             f"{vehicles_in_simulator},"
             f"{vehicles_in_queue},"
+            f"{vehicles_spawned},"
+            f"{vehicles_arrived},"
             f"{runtime}"
             "\n"
         )
